<?php
class IDM
{
/*
 *$Header: /src/rx/admin/app/IDM.php
 *=================================================================
 * FILENAME
 *    IDM.php
 *
 * DESCRIPTION
 *    This script contains functions related to
 *    registration and unregistration with ID Management
 *=================================================================
 *                 Copyright (c) Microsoft India
 *=================================================================
*/

	private $conn;
	private $guid;

	
	public function __construct()
	{
		global $global_conn_obj, $CERT_PATH, $SLASH;
		$this->acs_obj = new ACS();
		$this->metering_obj  = new Metering();
		$this->conn = $global_conn_obj;
		
		$this->cert_path = CERT_PATH ."certs/azure.crt";		
	}
	
	public function registerContainer($access_token, $get_data = '')
	{
		$acs_info = $guid = '';
		$this->acs_token = $access_token;
		$this->container_status = FAILURE;
		
		//This value is set once the register container is success and when fetching the container Id.
		$this->get_container_data = $get_data;

		//Fetching Self signed certificate data
		$self_signed_cert_data = file_get_contents($this->cert_path);
		$certificate_data = $this->metering_obj->getCertAndPrivateKey($self_signed_cert_data);		
		$self_sign_cert = $certificate_data["certificate"];
		
		//Setting the IDM url from the vault credentials and corresponding headers 
		$this->setIdmProperties();
		
		$curl_data["post_data"] = '<RegisterContainerInputArgs xmlns:i="http://www.w3.org/2001/XMLSchema-instance" xmlns="http://schemas.microsoft.com/windowsazure"><Details><AgentType>InMage</AgentType><ContainerType>InMage</ContainerType><FriendlyName>RegisterInMageContainer_'. HOST_GUID .'</FriendlyName><RawCertData>'.$self_sign_cert.'</RawCertData><UniqueName>'. HOST_GUID .'</UniqueName></Details></RegisterContainerInputArgs>';
		$curl_data["url"] = $this->url;
		$curl_data["headers"] = $this->headers;
		
		$this->metering_obj->metering_log("IDM call --- registerContainer");
		//Sending request to ID management to register container or to fetch the container id for the registered container.
		$register_container_output = $this->metering_obj->execute($curl_data, 1);

		if($register_container_output["http_code"] == HTTP_SUCCESS or $register_container_output["http_code"] == HTTP_ACCEPTED)
		{			
			$this->container_status = ASR_SUCCESS;
			
			$this->metering_obj->metering_log("IDM call --- registerContainer register_container_output :: ". print_r($register_container_output, true));
			# Fetching acs info by parsing the register container status output.
			if($register_container_output["RegisterContainer"] && $register_container_output["http_code"] == HTTP_SUCCESS && $get_data == 1)	
			{
				$acs_info = simplexml_load_string($register_container_output["RegisterContainer"]);
				$condition = "Registration Success";
			}	
			elseif(!$this->get_container_data) 
			{
				$condition = "Registration InProgress";		
				$guid = $this->guid;
			}	
		}
		else $condition = "Registration Failed";
		
		//Updating the subscriptionDetails table either contianerGUID or containerID.
		$this->metering_obj->updateSubscriptionData($guid, $acs_info,'',$condition);
		$this->metering_obj->metering_log("IDM call --- registerContainer container_status :: ". $this->container_status);
		return $this->container_status;
	}
	
	public function registerContainerStatus()
	{
		$acs_info = $this->acs_obj->getAccessTokenforIDM();
		$this->acs_token = $acs_info->access_token;
		$this->get_container_data =  1;
		$this->container_status = FAILURE;
		
		if(!$this->acs_token->error)
		{
			$this->setIdmProperties();
			$curl_data["url"] = $this->url."/status";
			$curl_data["headers"] = $this->headers;
			
			$this->metering_obj->metering_log("IDM call --- registerContainerStatus");		
			$register_container_status = $this->metering_obj->execute($curl_data, 0);
			
			if($register_container_status["http_code"] == HTTP_SUCCESS)
			{
				$container_xml = simplexml_load_string($register_container_status["RegisterContainerStatus"]);
				$this->container_status = $container_xml->State;
				$condition = "RX";
			} 
			else $condition = "Registration Failed";
			$this->metering_obj->updateSubscriptionData('','','',$condition);
		}
		
		return $this->container_status;
	}
	
	private function setIdmProperties()
	{
		$idmgmt_info = explode("idmgmtstampuri=",urldecode($this->acs_token));		
		$idmgmt_uri = explode("&",$idmgmt_info[1]);

		$vault_cert_data = $this->metering_obj->parseVaultCert();
		$vault_resource_name = $vault_cert_data->ResourceName;
		
		$this->url = $idmgmt_uri[0]."/restapi/resources/HyperVRecoveryManagerVault/$vault_resource_name/containers/". HOST_GUID;		
				
		if(!$this->get_container_data) 	$this->guid = $this->metering_obj->generateGUID();
		else $this->guid = $this->conn->sql_get_value("ASRSubscriptionDetails","containerGUID","1");
		
		$this->headers = array(
			'Accept: application/xml',
			'Authorization: Basic ACSOAuth2Token '.$this->acs_token,
			'Content-Type: application/xml',
			'WorkitemClientContextHeader: '.$this->guid
			);
	}
}
?>